@@ -8,7 +8,10 @@ test_that("fetchSCAN() works", {
 
   ## sample data
   x <<- fetchSCAN(site.code=2001, year=c(2014))
-
+  
+  # skip on error
+  skip_if(is.null(x))
+  
   # standard request
   expect_true(inherits(x, 'list'))
 
@@ -19,7 +22,10 @@ test_that("fetchSCAN() returns the right kind of data", {
   skip_if_offline()
 
   skip_on_cran()
-
+  
+  # skip on error
+  skip_if(is.null(x))
+  
   # metadata + some sensor data
   expect_true(inherits(x, 'list'))
   expect_true(inherits(x$metadata, 'data.frame'))
